# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.3] - 2023-05-23

### Fixed

- Add the link to new `grid` in Horton3.

## [0.0.2] - 2023-05-23

### Added

- Add Horton `espfit` module

## [0.0.1] - 2023-05-23

### Added

- The Python 3.10+ support
- Tests
